# Aliza Natural Language Application

This is a natural language "chatbot" application built using Spring Boot and Thymeleaf as a client that connects to the OpenAI API.  The OpenAI server uses a Transformer based Large Language Model to parse and respond to user queries.  Its neural network has already been trained by the OpenAI group, but can be optimized by "[fine tuning](https://platform.openai.com/docs/guides/fine-tuning)."

## Requirements

For building the application you need:

- [JDK 17](https://www.oracle.com/java/technologies/javase/jdk17-archive-downloads.html)
- [Maven 3](https://maven.apache.org)

You will also want to update the [application.properties](src\main\resources\application.properties) file and provide values for openai.key and openai.alias.  You may optionally provide values for server port and for openai.model.

The openai.key may be obtained by [creating an OpenAI account](https://platform.openai.com/signup) and then going to the [API Key page](https://platform.openai.com/account/api-keys) to generate a new key.  This key uniquely identifies your OpenAI account.

The openai.alias is simply a name for the account which is displayed in the logfiles.  Neither the key nor the alias are displayed to the user but the alias is written to the logfile, which may assist in troubleshooting.

The port value determines the application port and openai.model value chooses the selected GPT model.  Your model can be one of those provided by OpenAI or can be used to select a user-trained model for completions.

## Building the application

The application is built using the following command line:

```shell
mvn clean install
```

This will create an executable jarfile that contains embedded Tomcat in the `target` subdirectory.

## Running the application locally

There are several ways to run a Spring Boot application on your local machine. One way is to execute the `main` method in the `Aliza` class from your IDE.

Alternatively you can use the [Spring Boot Maven plugin](https://docs.spring.io/spring-boot/docs/current/reference/html/build-tool-plugins-maven-plugin.html) like so:

```shell
mvn spring-boot:run
```

Or after building the application, you can simply launch the jarfile from Java:

```shell
java -jar target/aliza-4.0-RELEASE.jar
```

Once the application is running, it can be accessed by any web browser at the port defined in the [application.properties](src\main\resources\application.properties) file.  So simply type this URL into the browser's address bar:

localhost:4222
