package com.parhamdata.aliza.controller;

import com.parhamdata.aliza.dto.DisplayDto;
import com.parhamdata.aliza.dto.RequestDto;
import com.parhamdata.aliza.dto.ResponseDto;
import com.parhamdata.aliza.service.ChatService;
import com.parhamdata.aliza.service.MarkdownToHtml;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@RestController
public class ChatController {

    @Value("${openai.alias}")
    private String openaiAlias;

    @Value("${openai.model}")
    private String openaiModel;

    @Value("${openai.temperature}")
    private Double openaiTemperature;

    @Autowired
	private MarkdownToHtml textConverter;

    @Autowired
    private ChatService chatService;

    public ChatController(ChatService chatService) {
        this.chatService = chatService;
    }

    Logger logger = LoggerFactory.getLogger(ChatController.class);

    @GetMapping("/chat")
    public DisplayDto chat(@RequestParam String prompt) {

        String openaiResponse = "No response.";
        RequestDto request = new RequestDto(prompt, openaiModel, openaiTemperature);
        logger.info("{} request below:\n{}", openaiAlias, request.toString());
        
        ResponseDto response = chatService.send(request);

        logger.info("{} response below:\n{}", openaiAlias, response);
        
        if (response != null && response.getChoices() != null && !response.getChoices().isEmpty()) {
            openaiResponse = response.getChoices().get(0).getMessage().getContent();
        }

        return new DisplayDto(prompt, openaiResponse, textConverter.markdownToHtml(openaiResponse));
    }

}
